import { DataModel } from '@lumino/datagrid';
import { View } from './view';
import { DataSource } from '../datasource';
/**
 * A View implementation for immutable in-memory JSON data.
 *
 * Note: Most of this is just repurposed from JSONModel, and can likely be
 * streamlined quite a bit.
 */
export declare class StreamingView extends View {
    /**
     * Create a view with streaming data.
     *
     * @param options - The datasource for initializing the view.
     */
    constructor(options: StreamingView.IOptions);
    /**
     * Get the row count for a region in the view.
     *
     * @param region - The row region of interest.
     *
     * @returns - The row count for the region.
     */
    rowCount(region: DataModel.RowRegion): number;
    /**
     * Get the data value for a cell in the view.
     *
     * @param region - The cell region of interest.
     *
     * @param row - The row index of the cell of interest.
     *
     * @param column - The column index of the cell of interest.
     *
     * @param returns - The data value for the specified cell.
     *
     * #### Notes
     * A `missingValue` as defined by the schema is converted to `null`.
     */
    data(region: DataModel.CellRegion, row: number, column: number): any;
    setDataRange(r1: number, r2: number, c1: number, c2: number, value: DataSource): void;
    setData(value: any, row: number, column: number): void;
    setRowCount(rowCount: number): void;
    private _streamed_data;
    private _rowCount;
}
export declare namespace StreamingView {
    interface IOptions {
        /**
         * The datasource.
         */
        datasource: DataSource;
        /**
         * The row number of the grid.
         */
        rowCount: number;
    }
}
