import { DataModel } from '@lumino/datagrid';
import { StreamingView } from './streamingview';
import { TransformStateManager } from './transformStateManager';
import { ViewBasedJSONModel } from './viewbasedjsonmodel';
import { DataGridModel } from '../datagrid';
import { DataSource } from '../datasource';
interface IUnique {
    region: DataModel.CellRegion;
    column: string;
    values: any[];
}
/**
 * A view based data model implementation for in-memory JSON data.
 */
export declare class StreamingViewBasedJSONModel extends ViewBasedJSONModel {
    constructor(options: StreamingViewBasedJSONModel.IOptions);
    setModelRangeData(r1: number, r2: number, c1: number, c2: number, value: DataSource): void;
    /**
     * Returns a Promise that resolves to an array of unique values contained in
     * the provided column index.
     *
     * @param region - The CellRegion to retrieve unique values for.
     * @param column - The column to retrieve unique values for.
     */
    uniqueValues(region: DataModel.CellRegion, column: string): Promise<any[]>;
    updateDataset(options: StreamingViewBasedJSONModel.IOptions): void;
    updateCellValue(options: ViewBasedJSONModel.IUpdateCellValuesOptions): void;
    get currentView(): StreamingView;
    set currentView(view: StreamingView);
    /**
     * Handler for transformState.changed events.
     *
     * @param sender - TransformStateManager
     *
     * @param value - Event.
     */
    protected _transformStateChangedHandler(sender: TransformStateManager, value: TransformStateManager.IEvent): void;
    protected _currentView: StreamingView;
    protected _dataModel: DataGridModel;
    protected _unique?: IUnique;
}
export declare namespace StreamingViewBasedJSONModel {
    /**
     * An options object for initializing the data model.
     */
    interface IOptions extends ViewBasedJSONModel.IOptions {
        /**
         * The row number of the grid.
         */
        rowCount: number;
        dataModel: DataGridModel;
    }
}
export {};
