"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SortExecutor = exports.FilterExecutor = exports.TransformExecutor = void 0;
const datasource_1 = require("../datasource");
const moment = __importStar(require("moment"));
/**
 * An object that defines a data transformation executor.
 */
class TransformExecutor {
}
exports.TransformExecutor = TransformExecutor;
/**
 * A transformation that filters a single field by the provided operator and
 * value.
 *
 * Note: This is a WIP
 */
class FilterExecutor extends TransformExecutor {
    /**
     * Create a new transformation.
     *
     * @param options - The options for initializing the transformation.
     */
    constructor(options) {
        super();
        this._options = options;
    }
    /**
     * Apply a transformation to the provided data.
     *
     * @param input - The data to be operated on.
     */
    apply(input) {
        let filterFunc;
        const field = this._options.field;
        switch (this._options.operator) {
            case '>':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return target.isAfter(value, 'day');
                    }
                    return input.data[field][idx] > this._options.value;
                };
                break;
            case '<':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return target.isBefore(value, 'day');
                    }
                    return input.data[field][idx] < this._options.value;
                };
                break;
            case '<=':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return target.isSameOrBefore(value, 'day');
                    }
                    return input.data[field][idx] <= this._options.value;
                };
                break;
            case '>=':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return target.isSameOrAfter(value, 'day');
                    }
                    return input.data[field][idx] >= this._options.value;
                };
                break;
            case '=':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return target.isSame(value);
                    }
                    return input.data[field][idx] == this._options.value;
                };
                break;
            case '!=':
                filterFunc = (idx) => {
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const value = moment.default.utc(this._options.value);
                        return !target.isSame(value);
                    }
                    return input.data[field][idx] !== this._options.value;
                };
                break;
            case 'empty':
                filterFunc = (idx) => {
                    return input.data[field][idx] === null;
                };
                break;
            case 'notempty':
                filterFunc = (idx) => {
                    return input.data[field][idx] !== null;
                };
                break;
            case 'in':
                filterFunc = (idx) => {
                    const values = this._options.value;
                    return values.includes(input.data[field][idx]);
                };
                break;
            case 'between':
                filterFunc = (idx) => {
                    const values = this._options.value;
                    if (['date', 'datetime', 'time'].includes(this._options.dType)) {
                        const target = moment.default.utc(input.data[field][idx]);
                        const lowValue = moment.default.utc(values[0]);
                        const highValue = moment.default.utc(values[1]);
                        return target.isBetween(lowValue, highValue, 'day');
                    }
                    return (input.data[field][idx] > values[0] &&
                        input.data[field][idx] < values[1]);
                };
                break;
            case 'startswith':
                filterFunc = (idx) => {
                    return input.data[field][idx].startsWith(this._options.value);
                };
                break;
            case 'endswith':
                filterFunc = (idx) => {
                    return input.data[field][idx].endsWith(this._options.value);
                };
                break;
            case 'stringContains':
                filterFunc = (idx) => {
                    return String(input.data[field][idx])
                        .toLowerCase()
                        .includes(String(this._options.value).toLowerCase());
                };
                break;
            case 'contains':
                filterFunc = (idx) => {
                    return input.data[field][idx].includes(this._options.value);
                };
                break;
            case '!contains':
                filterFunc = (idx) => {
                    return !input.data[field][idx].includes(this._options.value);
                };
                break;
            case 'isOnSameDay':
                filterFunc = (idx) => {
                    const target = moment.default.utc(input.data[field][idx]);
                    const value = moment.default.utc(this._options.value);
                    return target.isSame(value, 'day');
                };
                break;
            default:
                throw 'unreachable';
        }
        const data = {};
        const indices = Array.from(Array(input.length).keys()).filter(filterFunc);
        // There is a better approach for this
        // We don't need to copy the data
        // We should always keep the datasource intact and
        // create the "views" in the transform's apply methods
        // The view would then keep the indices in memory and apply the sorting
        // upon data request
        for (const column of Object.keys(input.data)) {
            let i = 0;
            data[column] = [];
            for (const idx of indices) {
                data[column][i++] = input.data[column][idx];
            }
        }
        return new datasource_1.DataSource(data, input.fields, input.schema);
    }
}
exports.FilterExecutor = FilterExecutor;
/**
 * A transformation that sorts the provided data by the provided field.
 *
 * Note: This is a WIP
 */
class SortExecutor extends TransformExecutor {
    /**
     * Creates a new sort transformation
     *
     * @param options - The options for initializing the transformation.
     */
    constructor(options) {
        super();
        this._options = options;
    }
    /**
     * Apply a transformation to the provided data.
     *
     * Note: Currently ignores the `desc` parameter.
     *
     * @param input - The data to be operated on.
     */
    apply(input) {
        let sortFunc;
        const field = this._options.field;
        const columnDataType = this._options.dType;
        // Adding string checks within the sort function so we do
        // not have to mutate in-place the original types of the
        // values of the column into strings. This allows the
        // displayed values to maintain their original types but
        // be sorted as if they were all strings.
        const stringifyIfNeeded = (value) => {
            if (typeof value != 'string') {
                return String(value);
            }
            return value;
        };
        const isNaNorNull = (value) => {
            return (value === null ||
                (typeof value === 'number' && Number.isNaN(value)) ||
                (value instanceof Date && Number.isNaN(value.getTime())));
        };
        const nanIndices = Array.from(Array(input.length).keys()).filter((idx) => {
            return isNaNorNull(input.data[field][idx]);
        });
        const nonNanIndices = Array.from(Array(input.length).keys()).filter((idx) => {
            return !isNaNorNull(input.data[field][idx]);
        });
        if (columnDataType == 'string') {
            if (this._options.desc) {
                sortFunc = (a, b) => {
                    return stringifyIfNeeded(input.data[field][a]) <
                        stringifyIfNeeded(input.data[field][b])
                        ? 1
                        : -1;
                };
            }
            else {
                sortFunc = (a, b) => {
                    return stringifyIfNeeded(input.data[field][a]) >
                        stringifyIfNeeded(input.data[field][b])
                        ? 1
                        : -1;
                };
            }
        }
        else {
            if (this._options.desc) {
                sortFunc = (a, b) => {
                    return input.data[field][a] < input.data[field][b] ? 1 : -1;
                };
            }
            else {
                sortFunc = (a, b) => {
                    return input.data[field][a] > input.data[field][b] ? 1 : -1;
                };
            }
        }
        const data = {};
        let indices = nonNanIndices.sort(sortFunc);
        indices = indices.concat(nanIndices);
        // There is a better approach for this
        // We don't need to copy the data
        // We should always keep the datasource intact and
        // create the "views" in the transform's apply methods
        // The view would then keep the indices in memory and apply the sorting
        // upon data request
        for (const column of Object.keys(input.data)) {
            let i = 0;
            data[column] = [];
            for (const idx of indices) {
                data[column][i++] = input.data[column][idx];
            }
        }
        return new datasource_1.DataSource(data, input.fields, input.schema);
    }
}
exports.SortExecutor = SortExecutor;
//# sourceMappingURL=transformExecutors.js.map