import { TextRenderer, CellRenderer, GraphicsContext } from '@lumino/datagrid';
import { UniqueValueStateManager, InteractiveFilterDialog } from './filterMenu';
/**
 * A custom cell renderer for displaying the unique values of a column.
 */
export declare class FilterValueRenderer extends TextRenderer {
    constructor(options: FilterValueRenderer.IOptions);
    /**
     * Draw the text for the cell.
     *
     * @param gc - The graphics context to use for drawing.
     *
     * @param config - The configuration data for the cell.
     */
    drawText(gc: GraphicsContext, config: CellRenderer.CellConfig): void;
    private _getCheckedState;
    private _stateManager;
    private _dialog;
}
/**
 * The namespace for the `HeaderRenderer` class statics.
 */
export declare namespace FilterValueRenderer {
    /**
     * An options object for initializing a renderer.
     */
    interface IOptions {
        /**
         * The `UniqueValueStateManager` to be used by this renderer.
         */
        readonly stateManager: UniqueValueStateManager;
        /**
         * The `InteractiveFilterDialog` this renderer is used by.
         */
        readonly dialog: InteractiveFilterDialog;
        /**
         * The CSS color for drawing the text.
         */
        readonly backgroundColor: string;
        /**
         * The CSS color for drawing the text.
         */
        readonly textColor: string;
    }
}
