import { BasicSelectionModel } from '@lumino/datagrid';
import { Message } from '@lumino/messaging';
import { Dict, DOMWidgetModel, DOMWidgetView, ICallbacks, ISerializers, JupyterLuminoPanelWidget, WidgetModel, WidgetView } from '@jupyter-widgets/base';
import { ViewBasedJSONModel } from './core/viewbasedjsonmodel';
import { StreamingViewBasedJSONModel } from './core/streamingviewbasedjsonmodel';
import { CellRendererView } from './cellrenderer';
import { FeatherGrid } from './feathergrid';
import { StreamingFeatherGrid } from './streamingfeathergrid';
import { DataSource } from './datasource';
import '../style/jupyter-widget.css';
export declare class DataGridModel extends DOMWidgetModel {
    defaults(): {
        _model_module: any;
        _model_module_version: any;
        _view_name: string;
        _view_module: any;
        _view_module_version: any;
        _visible_rows: never[];
        _transforms: never[];
        baseRowSize: number;
        baseColumnSize: number;
        baseRowHeaderSize: number;
        baseColumnHeaderSize: number;
        headerVisibility: string;
        _data: {};
        renderers: {};
        corner_renderer: null;
        default_renderer: null;
        header_renderer: null;
        selection_mode: string;
        selections: never[];
        grid_style: {};
        editable: boolean;
        column_widths: {};
        horizontal_stripes: boolean;
        vertical_stripes: boolean;
        _transform_on_backend: boolean;
    };
    initialize(attributes: any, options: any): void;
    updateDataSync(sender: any, msg: any): void;
    syncTransformState(sender: any, value: any): void;
    updateData(): void;
    updateTransforms(): void;
    updateSelectionModel(): void;
    updateSelections(): void;
    get data(): DataSource;
    static serializers: ISerializers;
    static readonly model_name: string;
    static readonly model_module: any;
    static readonly model_module_version: any;
    static readonly view_name: string;
    static readonly view_module: any;
    static readonly view_module_version: any;
    data_model: ViewBasedJSONModel;
    selectionModel: BasicSelectionModel | null;
    synchingWithKernel: boolean;
    _view_callbacks: ICallbacks;
}
export declare class DataGridView extends DOMWidgetView {
    _createElement(tagName: string): HTMLElement;
    get pWidget(): any;
    _setElement(el: HTMLElement): void;
    manageResizeEvent: () => void;
    _processLuminoMessage(msg: Message, _super: any): void;
    processLuminoMessage(msg: Message): void;
    processPhosphorMessage(msg: Message): void;
    protected _createGrid(): FeatherGrid;
    render(): Promise<void>;
    private handleColumnAutoFit;
    private updateRenderers;
    updateGridStyle(): void;
    set isLightTheme(value: boolean);
    get isLightTheme(): boolean;
    private updateGridRenderers;
    private _initializeTheme;
    renderers: Dict<CellRendererView>;
    corner_renderer: CellRendererView;
    default_renderer: CellRendererView;
    header_renderer: CellRendererView;
    grid: FeatherGrid;
    luminoWidget: JupyterLuminoPanelWidget;
    model: DataGridModel;
    backboneModel: DataGridModel;
    horizontal_stripes: boolean;
    vertical_stripes: boolean;
    private _isLightTheme;
}
export { BarRendererModel, BarRendererView, ImageRendererModel, ImageRendererView, HyperlinkRendererModel, HyperlinkRendererView, TextRendererModel, TextRendererView, HtmlRendererModel, HtmlRendererView, } from './cellrenderer';
export { VegaExprModel, VegaExprView } from './vegaexpr';
export declare namespace DataGridModel {
    interface IData {
        data: DataSource;
        schema: ISchema;
        fields: {
            [key: string]: null;
        }[];
    }
    interface IField {
        readonly name: string;
        readonly type: string;
        readonly rows: any[];
    }
    interface ISchema {
        readonly fields: IField[];
        readonly primaryKey: string | string[];
        readonly primaryKeyUuid: string;
    }
}
export declare class StreamingDataGridModel extends DataGridModel {
    defaults(): {
        _model_name: string;
        _view_name: string;
        _row_count: number;
        _data: {};
        _debounce_delay: number;
        _transform_on_backend: boolean;
        _model_module: any;
        _model_module_version: any;
        _view_module: any;
        _view_module_version: any;
        _visible_rows: never[];
        _transforms: never[];
        baseRowSize: number;
        baseColumnSize: number;
        baseRowHeaderSize: number;
        baseColumnHeaderSize: number;
        headerVisibility: string;
        renderers: {};
        corner_renderer: null;
        default_renderer: null;
        header_renderer: null;
        selection_mode: string;
        selections: never[];
        grid_style: {};
        editable: boolean;
        column_widths: {};
        horizontal_stripes: boolean;
        vertical_stripes: boolean;
    };
    initialize(attributes: any, options: any): void;
    updateData(): void;
    requestData(r1: number, r2: number, c1: number, c2: number): void;
    static readonly model_name: string;
    static readonly view_name: string;
    data_model: StreamingViewBasedJSONModel;
}
export declare class StreamingDataGridView extends DataGridView {
    initialize(parameters: WidgetView.IInitializeParameters<WidgetModel>): void;
    protected _createGrid(): StreamingFeatherGrid;
    private requestData;
    model: StreamingDataGridModel;
    grid: StreamingFeatherGrid;
}
