import { Dict } from '@jupyter-widgets/base';
export declare class DataSource {
    constructor(data: Dict<any[]>, fields: any[], schema: any, computeSchema?: boolean);
    get data(): Dict<any[]>;
    get fields(): any[];
    get schema(): DataSource.ISchema;
    get columns(): string[];
    get length(): number;
    setColumns(columnNames: string[]): void;
    private _createSchema;
    private _data;
    private _fields;
    private _schema;
    private _columns;
}
export declare namespace DataSource {
    /**
     * An object which describes a column of data in the model.
     *
     * #### Notes
     * This is based on the JSON Table Schema specification:
     * https://specs.frictionlessdata.io/table-schema/
     */
    interface IField {
        /**
         * The name of the column.
         *
         * This is used as the key to extract a value from a data record.
         */
        readonly name: string;
        /**
         * The type of data held in the column.
         */
        readonly type: string;
        /**
         * An array of the column labels per header row.
         */
        readonly rows: any[];
    }
    interface ISchema {
        /**
         * The fields which describe the view columns.
         *
         * Primary key fields are rendered as row header columns.
         */
        readonly fields: DataSource.IField[];
        /**
         * The values to treat as "missing" data.
         *
         * Missing values are automatically converted to `null`.
         */
        readonly missingValues?: string[];
        /**
         * The field names which act as primary keys.
         *
         * Primary key fields are rendered as row header columns.
         */
        readonly primaryKey: string | string[];
        /**
         * The name of the unique identifier in the primary key array
         */
        readonly primaryKeyUuid: string;
    }
}
