import { CellGroup } from '@lumino/datagrid';
export declare namespace ArrayUtils {
    /**
     * Returns the locations of multi-index column arrays.
     * @param model the datamodel instance.
     */
    function generateMultiIndexArrayLocations(model: any): number[];
    /**
     * Returns an array of [mergedCellSiblingGroup]. Each element represents a row of columns.
     * The 0th row will be the top level group, and the n-th will be the last.
     * @param model the data model.
     * @param multiIndexArrayLocations index-based locations of all mutli-index columns.
     */
    function generateColMergedCellLocations(model: any, multiIndexArrayLocations: number[]): number[][][][];
    /**
     * Returns an array of [mergedCellSiblingGroup]. Each element represents a column of rows.
     * The 0th row will be the top level group, and the n-th will be the last.
     * @param model data model with schema and data fields
     * @returns index-based locations of all mutli-index rows.
     */
    function generateRowMergedCellLocations(model: any): number[][][][];
    /**
     * Checks whether the merged cell ranges conform to a valid hierarchy.
     * @param retVal boolean
     */
    function validateMergingHierarchy(retVal: number[][][][]): boolean;
    /**
     * Generates a list of merged column cell groups for use in the data model.
     * @param indexLists index-based location of merged columns
     * @returns CellGroup[]
     */
    function generateColumnCellGroups(indexLists: number[][][][]): CellGroup[];
    /**
     * Generates a list of merged row cell groups for use in the data model.
     * @param indexLists index-based location of merged rows.
     * @returns CellGroup[]
     */
    function generateRowCellGroups(indexLists: number[][][][]): CellGroup[];
}
export type Scalar = null | boolean | number | string;
export declare namespace Scalar {
    function isScalar(x: any): x is Scalar;
}
export declare namespace Theme {
    function getComputedColor(name: string): string;
    function getCSSColor(name: string, opacity?: number): any;
    function getBackgroundColor(index?: number, opacity?: number): any;
    function getFontColor(index?: number, opacity?: number): any;
    function getBorderColor(index?: number, opacity?: number): any;
    function getBrandColor(index?: number, opacity?: number): any;
}
