"use strict";
// Copyright (c) NumFOCUS.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.VegaExprView = exports.VegaExprModel = void 0;
const vegaExpressions = require('vega-expression');
const vegaFormat = require('vega-format');
const vegaFunctions = require('vega-functions');
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
// Newer versions of vega-functions require a locale property.
// When using vega-functions from within Vega, this is provided,
// but because we're using vega-functions separately, we need to
// manually create and bind that locale context to the format function.
const locale = vegaFormat.defaultLocale();
const dataflow = { context: { dataflow: { locale: () => locale } } };
for (const name in vegaFunctions.functionContext) {
    vegaFunctions.functionContext[name] =
        vegaFunctions.functionContext[name].bind(dataflow);
}
class VegaExprModel extends base_1.WidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: VegaExprModel.model_name, _model_module: VegaExprModel.model_module, _model_module_version: VegaExprModel.model_module_version, value: 'default_value' });
    }
    initialize(attributes, options) {
        super.initialize(attributes, options);
        const codegen_params = {
            whitelist: ['cell', 'default_value', 'functions'],
            globalvar: 'cell',
            functions: (codegen) => {
                const fn = vegaExpressions.functions(codegen);
                for (const name in vegaFunctions.functionContext) {
                    fn[name] = 'functions.' + name;
                }
                return fn;
            },
        };
        this._codegen = vegaExpressions.codegen(codegen_params);
        this.updateFunction();
        // @ts-ignore
        this.on('change:value', this.updateFunction.bind(this));
    }
    process(config, defaultValue) {
        return this._function(config, defaultValue, vegaFunctions.functionContext);
    }
    _processRegex(match, data) {
        const parsedMatch = data.match(/\[(.*?)\]/g);
        const column = parsedMatch[0];
        const columnMatch = column.match(/\[(.*?)\]/)[1];
        if (parsedMatch.length === 1) {
            // Column indexing for regular element.
            return `cell.metadata.data(cell.row, ${columnMatch})`;
        }
        else {
            // Column indexing for a compound element.
            const rest = parsedMatch.splice(1);
            return `cell.metadata.data(cell.row, ${columnMatch})${rest.join('')}`;
        }
    }
    /**
     * Augments transpiled JS code output from vega with
     * datamodel calls for condition validation.
     * @param parsedValue JS code (string) generated from a vega expression
     */
    _augmentExpression(parsedValue) {
        let codeToProcess = parsedValue.code;
        codeToProcess = codeToProcess.replace(
        //  The original regex below is not compatible with safari (missing lookbehind)
        // /(?<=cell.metadata.data)(?<data>(\[(.*?)\])+)(?=)/g,
        /cell.metadata.data(?<data>(\[(.*?)\])+)/g, this._processRegex);
        parsedValue.code = codeToProcess;
        return parsedValue;
    }
    updateFunction() {
        let parsedValue = this._codegen(
        // @ts-ignore
        vegaExpressions.parse(this.get('value')));
        parsedValue = this._augmentExpression(parsedValue);
        this._function = Function('cell', 'default_value', 'functions', '"use strict";return(' + parsedValue.code + ')');
    }
}
exports.VegaExprModel = VegaExprModel;
VegaExprModel.model_name = 'VegaExprModel';
VegaExprModel.model_module = version_1.MODULE_NAME;
VegaExprModel.model_module_version = version_1.MODULE_VERSION;
VegaExprModel.view_name = 'VegaExprView';
VegaExprModel.view_module = version_1.MODULE_NAME;
VegaExprModel.view_module_version = version_1.MODULE_VERSION;
class VegaExprView extends base_1.WidgetView {
    process(config, defaultValue) {
        return this.model.process(config, defaultValue);
    }
}
exports.VegaExprView = VegaExprView;
//# sourceMappingURL=vegaexpr.js.map